@@ -8,6 +8,7 @@ from urllib import parse
 from PIL import Image
 
 from . import biblio, config, dfnpanels, h, func, t, messages as m, idl, repository
+from .translate import _
 
 if t.TYPE_CHECKING:
     import widlparser  # pylint: disable=unused-import
@@ -188,12 +189,12 @@ def addImplicitAlgorithms(doc: t.SpecT) -> None:
                 el.set("data-algorithm-for", dfnFor)
         elif len(dfns) == 0:
             m.die(
-                "Algorithm container has no name, and there is no <dfn> to infer one from.",
+                "Algorithm container has no name, and there is no <dfn> to infer one from. Please set the algorithm='name here' attribute.",
                 el=el,
             )
         else:
             m.die(
-                "Algorithm container has no name, and there are too many <dfn>s to choose which to infer a name from.",
+                "Algorithm container has no name, and there are too many <dfn>s to choose which to infer a name from. Please set the algorithm='name here' attribute.",
                 el=el,
             )
 
@@ -466,9 +467,14 @@ def fillInterDocumentReferenceFromShepherd(doc: t.SpecT, el: t.ElementT, specNam
     h.removeAttr(el, "data-link-spec", "spec-section")
 
     # Mark this as a used biblio ref
-    specData = doc.refs.specs[specName]
-    bib = biblio.SpecBiblioEntry(specData)
-    registerBiblioUsage(doc, bib, el=el)
+    biblioRef = doc.refs.getBiblioRef(
+        specName,
+        status=doc.md.defaultRefStatus,
+        generateFakeRef=True,
+        quiet=False,
+    )
+    if biblioRef:
+        registerBiblioUsage(doc, biblioRef, el=el)
 
 
 def fillInterDocumentReferenceFromSpecref(doc: t.SpecT, el: t.ElementT, spec: str, section: str) -> None:
@@ -969,7 +975,7 @@ def decorateAutolink(doc: t.SpecT, el: t.ElementT, linkType: str, linkText: str,
 
     # Put an ID on every reference, so I can link to references to a term.
     if el.get("id") is None:
-        _, _, id = ref.url.partition("#")
+        unused1, unused2, id = ref.url.partition("#")  # pylint: disable=unused-variable
         if id:
             el.set("id", f"ref-for-{id}")
             el.set("data-silently-dedup", "")
@@ -987,7 +993,8 @@ def decorateAutolink(doc: t.SpecT, el: t.ElementT, linkType: str, linkText: str,
             typeRefs = doc.refs.queryAllRefs(linkFor=linkText, ignoreObsoletes=True)
             texts = sorted({ref.text for ref in typeRefs})
             if typeRefs:
-                titleText = "Expands to: " + " | ".join(texts)
+                titleText = _("Expands to: ") + " | ".join(texts)
+                assert titleText is not None
                 doc.typeExpansions[linkText] = titleText
         if titleText:
             el.set("title", titleText)
@@ -1006,7 +1013,7 @@ def removeMultipleLinks(doc: t.SpecT) -> None:
             continue
         paras[h.parentElement(el)][el.get("href", "")].append(el)
     for linkGroups in paras.values():
-        for _, links in linkGroups.items():
+        for links in linkGroups.values():
             if len(links) > 1:
                 for el in links[1:]:
                     el.tag = "span"
@@ -1047,7 +1054,9 @@ def processIssuesAndExamples(doc: t.SpecT) -> None:
             elif doc.md.issueTrackerTemplate:
                 remoteIssueURL = doc.md.issueTrackerTemplate.format(remoteIssueID)
             if remoteIssueURL:
-                h.appendChild(el, " ", h.E.a({"href": remoteIssueURL}, "[Issue #" + remoteIssueID + "]"))
+                h.appendChild(
+                    el, " ", h.E.a({"href": remoteIssueURL}, _("[Issue #{number}]").format(number=remoteIssueID))
+                )
     for el in h.findAll(".example:not([id])", doc):
         el.set("id", h.safeID(doc, "example-" + h.hashContents(el)))
     h.fixupIDs(doc, h.findAll(".issue, .example", doc))
@@ -1530,7 +1539,7 @@ def inlineRemoteIssues(doc: t.SpecT) -> None:
                 el,
                 h.E.a(
                     {"href": href, "class": "marker"},
-                    f"Issue #{data['number']} on GitHub: “{data['title']}”",
+                    _("Issue #{number} on GitHub: “{title}”").format(number=data["number"], title=data["title"]),
                 ),
                 *h.parseHTML(data["body_html"]),
             )
@@ -1551,11 +1560,11 @@ def addNoteHeaders(doc: t.SpecT) -> None:
     for el in h.findAll("[heading]", doc):
         h.addClass(doc, el, "no-marker")
         if h.hasClass(doc, el, "note"):
-            preText = "NOTE: "
+            preText = _("NOTE: ")
         elif h.hasClass(doc, el, "issue"):
-            preText = "ISSUE: "
+            preText = _("ISSUE: ")
         elif h.hasClass(doc, el, "example"):
-            preText = "EXAMPLE: "
+            preText = _("EXAMPLE: ")
         else:
             preText = ""
         h.prependChild(el, h.E.div({"class": "marker"}, preText, *h.parseHTML(el.get("heading", ""))))
